/***************************************************************************
 * Copyright (c) Johan Mabille, Sylvain Corlay, Wolf Vollprecht and         *
 * Martin Renou                                                             *
 * Copyright (c) QuantStack                                                 *
 * Copyright (c) Serge Guelton                                              *
 *                                                                          *
 * Distributed under the terms of the BSD 3-Clause License.                 *
 *                                                                          *
 * The full license is in the file LICENSE, distributed with this software. *
 ****************************************************************************/

#ifndef XSIMD_COMMON_HPP
#define XSIMD_COMMON_HPP

#include "./common/xsimd_common_arithmetic.hpp"
#include "./common/xsimd_common_bit.hpp"
#include "./common/xsimd_common_cast.hpp"
#include "./common/xsimd_common_complex.hpp"
#include "./common/xsimd_common_logical.hpp"
#include "./common/xsimd_common_math.hpp"
#include "./common/xsimd_common_memory.hpp"
#include "./common/xsimd_common_rounding.hpp"
#include "./common/xsimd_common_swizzle.hpp"
#include "./common/xsimd_common_trigo.hpp"

#endif
